@@ -6,7 +6,7 @@
 
 cd $SLURM_SUBMIT_DIR
 module purge
-module load system/Python-3.7.4
+module load devel/python/Python-3.7.9
 source env/bin/activate
 export PYTHONPATH=${PYTHONPATH}:"/path/to/solver/cplex/python/3.7/x86-64_linux"
 
