@@ -3,3 +3,5 @@ from .rxn_enum_functions import rxn_enum
 from .icut_functions import icut
 from .maxdist_functions import maxdist
 from .diversity_enum_functions import diversity_enum
+from .permutation_functions import permute_genelabels
+from .riptide_functions import imat_riptide_like
\ No newline at end of file
