@@ -2,7 +2,7 @@ import re
 import argparse
 import numpy as np
 import pandas as pd
-from symengine import sympify, Add, Mul, Max, Min, Pow, Symbol
+from symengine import sympify, Add, Mul, Max, Min, Pow
 from dexom_python.model_functions import read_model, save_reaction_weights
 pd.options.mode.chained_assignment = None
 
@@ -31,8 +31,8 @@ def replace_MulMax_AddMin(expression):
             # return expression.func(*replaced_args)
 
 
-def expression2qualitative(genes, column_list=None, proportion=0.25, method='keep', significant_genes='both',
-                           save=True, outpath='geneweights'):
+def expression2qualitative(genes, column_list=None, proportion=0.25, significant_genes='both', save=True,
+                           outpath='geneweights'):
     """
     Transforms gene expression values/ gene scores into qualitative gene weights
 
@@ -44,8 +44,6 @@ def expression2qualitative(genes, column_list=None, proportion=0.25, method='kee
         column indexes containing gene expression values to be transformed. If empty, all columns will be transformed
     proportion: tuple or float
         proportion of genes to be used for determining low and high gene expression
-    method: str
-        one of "max", "mean" or "keep". chooses how to deal with genes containing multiple conflicting expression values
     significant_genes: str
         one of "high", "low" or "both". chooses whether the conversion is applied only for the genes with
         highest expression, lowest epxression, or both
@@ -62,7 +60,6 @@ def expression2qualitative(genes, column_list=None, proportion=0.25, method='kee
     if isinstance(genes, pd.Series):
         genes = pd.DataFrame(genes)
         column_list = list(genes.columns)
-    genes = genes[genes.index == genes.index]  # eliminates NaN values in index
     if column_list is None:
         column_list = list(genes.columns)
     elif len(column_list) == 0:
@@ -76,15 +73,10 @@ def expression2qualitative(genes, column_list=None, proportion=0.25, method='kee
         highthreshold = 1-proportion
     else:
         lowthreshold, highthreshold = proportion
+    genes = genes.reset_index().dropna()
     for col in column_list:
         genecol = genes[col].copy()
         newgenes = genes[col].copy()
-        if method == 'max':
-            for x in set(newgenes.index):
-                newgenes[x] = newgenes[x].max()
-        elif method == 'mean':
-            for x in set(newgenes.index):
-                newgenes[x] = newgenes[x].mean()
         newgenes.sort_values(inplace=True)
         genecol.sort_values(inplace=True)
         newgenes[genecol < genecol.quantile(lowthreshold)] = -1.
@@ -97,6 +89,7 @@ def expression2qualitative(genes, column_list=None, proportion=0.25, method='kee
             print('applying expression2qualitative only on genes with lowest expression')
             newgenes[newgenes == 1.] = 0.
         genes[col] = newgenes
+    genes.set_index(genes.columns[0], inplace=True)
     for x in genes.index:
         if isinstance(x, float):
             genes.index = genes.index.astype(int)
@@ -164,8 +157,8 @@ def apply_gpr(model, gene_weights, save=True, filename='reaction_weights', dupli
         if len(rxn.genes) > 0:
             gen_list = [g.id for g in rxn.genes]
             expr_split = rxn.gene_reaction_rule.replace('(', '( ').replace(')', ' )').split()
-            expr_split = ['g_' + re.sub(r':|\.|-', '_', s) if s in gen_list else s for s in expr_split]
-            new_weights = {'g_' + re.sub(r':|\.|-', '_', g): gene_weight_dict.get(g, null) for g in gen_list}
+            expr_split = ['g_' + re.sub(r'[:.,;/-]', '_', s) if s in gen_list else s for s in expr_split]
+            new_weights = {'g_' + re.sub(r'[:.,;/-]', '_', g): gene_weight_dict.get(g, null) for g in gen_list}
             expression = ' '.join(expr_split).replace(' or ', ' * ').replace(' and ', ' + ')
             weight = replace_MulMax_AddMin(sympify(expression)).subs(new_weights)
             reaction_weights[rxn.id] = weight
@@ -211,7 +204,6 @@ def _main():
         score_columns = list(genes.columns)
     else:
         score_columns = args.gene_score.split(',')
-    print(score_columns)
 
     if args.convert:
         proportion = args.quantiles.split('_')
@@ -225,8 +217,7 @@ def _main():
             proportion = (float(proportion[0]), float(proportion[1]))
         else:
             ValueError('The quantiles argument was provided in an incorrect format.')
-        print(proportion)
-        genes = expression2qualitative(genes=genes, column_list=score_columns, proportion=proportion, method='keep',
+        genes = expression2qualitative(genes=genes, column_list=score_columns, proportion=proportion,
                                        significant_genes=args.significant, save=True,
                                        outpath=args.output+'_qual_geneweights')
     if len(score_columns) == 1:
